@@ -352,7 +352,7 @@ drdid_rc <-function(y, post, D, covariates, i.weights = NULL,
   #-----------------------------------------------------------------------------
   if (boot == FALSE) {
     # Estimate of standard error
-    se.dr.att <- stats::sd(dr.att.inf.func)/sqrt(n)
+    se.dr.att <- stats::sd(dr.att.inf.func)*sqrt(n-1)/(n)
     # Estimate of upper boundary of 95% CI
     uci <- dr.att + 1.96 * se.dr.att
     # Estimate of lower boundary of 95% CI
