@@ -1,7 +1,8 @@
 # Bootrstapped IPW Difference-in-Differences with Panel Data
 # 2 periods and 2 groups
 
-wboot.ipw.panel <- function(nn, n, deltaY, D, int.cov, i.weights){
+wboot.ipw.panel <- function(nn, n, deltaY, D, int.cov, i.weights,
+                            trim.level = 0.995){
   #-----------------------------------------------------------------------------
   v <- stats::rexp(n)
   #v <- v / mean(v)
@@ -16,8 +17,10 @@ wboot.ipw.panel <- function(nn, n, deltaY, D, int.cov, i.weights){
                                             intercept = FALSE,
                                             method = 3)$fitted.values)
   ps.b <- pmin(ps.b, 1 - 1e-6)
+  trim.ps <- (ps.b < 1.01)
+  trim.ps[D==0] <- (ps.b[D==0] < trim.level)
   # Compute IPW estimator
-  att.b <- mean(b.weights * (D - ps.b * (1 - D)/(1 - ps.b)) * deltaY) / mean(b.weights * D)
+  att.b <- mean(b.weights * trim.ps * (D - ps.b * (1 - D)/(1 - ps.b)) * deltaY) / mean(b.weights * D)
 
   #-----------------------------------------------------------------------------
   return(att.b)
