@@ -7,7 +7,7 @@
 wols_rc <- function(y, post, D, int.cov, pscore, i.weights, pre = NULL, treat = FALSE){
   #-----------------------------------------------------------------------------
   # Do not divide by zero
-  #pscore <- pmin(pscore, 1 - 1e-16)
+  #pscore <- pmin(pscore, 1 - 1e-6)
   or.weights <- as.vector(i.weights * pscore/(1 - pscore))
 
   if((pre == T) & (treat==T)) {
@@ -23,9 +23,17 @@ wols_rc <- function(y, post, D, int.cov, pscore, i.weights, pre = NULL, treat =
     subs <- (D==0)*(post==1)
   }
   #Run weighted OLS
-  beta.wls <- stats::coef(stats::lm(y ~ -1 + int.cov,
-                                    subset = subs==1,
-                                    weights = or.weights))
+  # beta.wls <- stats::coef(stats::lm(y ~ -1 + int.cov,
+  #                                   subset = subs==1,
+  #                                   weights = or.weights))
+  subs_filter <- (subs == 1)
+  beta.wls <- stats::coef(fastglm::fastglm(
+                          x = int.cov[subs_filter, , drop = FALSE],
+                          y = y[subs_filter],
+                          weights = or.weights[subs_filter],
+                          family = gaussian(link = "identity")
+  ))
+
   if(anyNA(beta.wls)){
     stop("Outcome regression model coefficients have NA components. \n Multicollinearity (or lack of variation) of covariates is a likely reason")
   }
