@@ -140,21 +140,23 @@ test_that("Analytical and bootstrapped std errors are similar: RC", {
                          panel = FALSE,
                          boot = FALSE)
 
-  dr_trad1.did_rc <- drdid_rc1(dta_long$y,
-                              dta_long$post,
-                              dta_long$d,
-                              dta_long[,5:8], boot = FALSE)
+  dr_trad1.did_rc <- drdid_rc1(y = dta_long$y,
+                              post = dta_long$post,
+                              D = dta_long$d,
+                              covariates = cbind(1, dta_long[,5:8]),
+                              boot = FALSE)
+
 
   dr_imp1.did_rc <- drdid_imp_rc1(dta_long$y,
                                  dta_long$post,
                                  dta_long$d,
-                                 dta_long[,5:8], boot = FALSE)
+                                 cbind(1,dta_long[,5:8]), boot = FALSE)
   #-----------------------------------------------------------------------------
   # Now with bootstrap (weighted)
   or.did_rc2 <- reg_did_rc(dta_long$y,
                            dta_long$post,
                            dta_long$d,
-                           dta_long[,5:8],
+                           cbind(1,dta_long[,5:8]),
                            boot = TRUE,
                            boot.type = "weighted",
                            nboot = nboot)
@@ -162,7 +164,7 @@ test_that("Analytical and bootstrapped std errors are similar: RC", {
   std_ipw.did_rc2 <- std_ipw_did_rc(dta_long$y,
                                     dta_long$post,
                                     dta_long$d,
-                                    dta_long[,5:8],
+                                    cbind(1,dta_long[,5:8]),
                                     boot = TRUE,
                                     boot.type = "weighted",
                                     nboot = nboot)
@@ -170,7 +172,7 @@ test_that("Analytical and bootstrapped std errors are similar: RC", {
   ipw.did_rc2 <- ipw_did_rc(dta_long$y,
                             dta_long$post,
                             dta_long$d,
-                            dta_long[,5:8],
+                            cbind(1,dta_long[,5:8]),
                             boot = TRUE,
                             boot.type = "weighted",
                             nboot = nboot)
@@ -178,7 +180,7 @@ test_that("Analytical and bootstrapped std errors are similar: RC", {
   dr_trad.did_rc2 <- drdid_rc(dta_long$y,
                               dta_long$post,
                               dta_long$d,
-                              dta_long[,5:8],
+                              cbind(1,dta_long[,5:8]),
                               boot = TRUE,
                               boot.type = "weighted",
                               nboot = nboot)
@@ -186,7 +188,7 @@ test_that("Analytical and bootstrapped std errors are similar: RC", {
   dr_imp.did_rc2 <- drdid_imp_rc(dta_long$y,
                                  dta_long$post,
                                  dta_long$d,
-                                 dta_long[,5:8],
+                                 cbind(1,dta_long[,5:8]),
                                  boot = TRUE,
                                  boot.type = "weighted",
                                  nboot = nboot)
@@ -194,7 +196,7 @@ test_that("Analytical and bootstrapped std errors are similar: RC", {
   dr_trad1.did_rc2 <- drdid_rc1(dta_long$y,
                                dta_long$post,
                                dta_long$d,
-                               dta_long[,5:8],
+                               cbind(1,dta_long[,5:8]),
                                boot = TRUE,
                                boot.type = "weighted",
                                nboot = nboot)
@@ -202,7 +204,7 @@ test_that("Analytical and bootstrapped std errors are similar: RC", {
   dr_imp1.did_rc2 <- drdid_imp_rc1(dta_long$y,
                                   dta_long$post,
                                   dta_long$d,
-                                  dta_long[,5:8],
+                                  cbind(1,dta_long[,5:8]),
                                   boot = TRUE,
                                   boot.type = "weighted",
                                   nboot = nboot)
@@ -213,44 +215,44 @@ test_that("Analytical and bootstrapped std errors are similar: RC", {
   or.did_rc3 <- reg_did_rc(dta_long$y,
                            dta_long$post,
                            dta_long$d,
-                           dta_long[,5:8], boot = TRUE,
+                           cbind(1,dta_long[,5:8]), boot = TRUE,
                            boot.type ="multiplier",
                            nboot = nboot)
 
   std_ipw.did_rc3 <- std_ipw_did_rc(dta_long$y,
                                     dta_long$post,
                                     dta_long$d,
-                                    dta_long[,5:8], boot = TRUE,
+                                    cbind(1,dta_long[,5:8]), boot = TRUE,
                                     boot.type ="multiplier", nboot = nboot)
 
   ipw.did_rc3 <- ipw_did_rc(dta_long$y,
                             dta_long$post,
                             dta_long$d,
-                            dta_long[,5:8], boot = TRUE,
+                            cbind(1,dta_long[,5:8]), boot = TRUE,
                             boot.type ="multiplier", nboot = nboot)
 
   dr_trad.did_rc3 <- drdid_rc(dta_long$y,
                               dta_long$post,
                               dta_long$d,
-                              dta_long[,5:8], boot = TRUE,
+                              cbind(1,dta_long[,5:8]), boot = TRUE,
                               boot.type ="multiplier", nboot = nboot)
 
   dr_imp.did_rc3 <- drdid_imp_rc(dta_long$y,
                                  dta_long$post,
                                  dta_long$d,
-                                 dta_long[,5:8], boot = TRUE,
+                                 cbind(1,dta_long[,5:8]), boot = TRUE,
                                  boot.type ="multiplier", nboot = nboot)
 
   dr_trad1.did_rc3 <- drdid_rc1(dta_long$y,
                                 dta_long$post,
                                 dta_long$d,
-                                dta_long[,5:8], boot = TRUE,
+                                cbind(1,dta_long[,5:8]), boot = TRUE,
                                 boot.type ="multiplier", nboot = nboot)
 
   dr_imp1.did_rc3 <- drdid_imp_rc1(dta_long$y,
                                    dta_long$post,
                                    dta_long$d,
-                                   dta_long[,5:8], boot = TRUE,
+                                   cbind(1,dta_long[,5:8]), boot = TRUE,
                                    boot.type ="multiplier", nboot = nboot)
 
   #-----------------------------------------------------------------------------
